@@ -7,10 +7,11 @@ beeps_per_day <- 10
 n_days <- 4
 
 valid <- unlist(lapply(1:n_participants, function(participant) {
-       rep(c(rep(TRUE, participant),
-             rep(FALSE, beeps_per_day - participant)),
-            n_days)
-   }))
+  rep(
+    c(rep(TRUE, participant), rep(FALSE, beeps_per_day - participant)),
+    n_days
+  )
+}))
 # building the valid col so that each participant has a different response rate,
 # participant 1 should have response rate 0.1, participant 2 = 0.2, etc.
 
@@ -18,10 +19,15 @@ valid <- unlist(lapply(1:n_participants, function(participant) {
 data <- data.frame(
   participant = rep(1:n_participants, each = n_days * beeps_per_day),
   valid = valid,
-  dates = rep(seq(as.Date("2023-01-01"),
-                  as.Date("2023-01-01") + (n_days-1),
-                  by = "day"),
-              each = beeps_per_day, n_participants)
+  dates = rep(
+    seq(
+      as.Date("2023-01-01"),
+      as.Date("2023-01-01") + (n_days - 1),
+      by = "day"
+    ),
+    each = beeps_per_day,
+    n_participants
+  )
 )
 
 # plot_response_rate depends on this function returning the correct df
@@ -33,22 +39,24 @@ test_that('response_rate_per_day works correctly', {
     time_col = dates
   )
 
-  for(participant in 1:n_participants){
+  for (participant in 1:n_participants) {
     expected_rate <- participant * 0.1
 
-    expect_equal(unique(data_plot
-                        [data_plot$participant == participant, ]$response_rate),
-                 expected_rate)
+    expect_equal(
+      unique(data_plot[data_plot$participant == participant, ]$response_rate),
+      expected_rate
+    )
   }
 })
 
 test_that('plot_response_rate returns a ggplot', {
-
   # we just expect an error
-  result <- plot_response_rate(data = data,
-                                valid_col = valid,
-                                participant_col = participant,
-                                time_col = dates)
+  result <- plot_response_rate(
+    data = data,
+    valid_col = valid,
+    participant_col = participant,
+    time_col = dates
+  )
 
   expect_true(ggplot2::is_ggplot(result))
 })
